=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2005-10-20 02:52:44 +0000
+++ bzrlib/commit.py	2005-10-26 10:03:47 +0000
@@ -206,8 +206,10 @@
         self.allow_pointless = allow_pointless
         self.revprops = revprops
 
-        if strict and branch.unknowns():
-            raise StrictCommitFailed()
+        if strict:
+            # raise an exception as soon as we find a single unknown.
+            for unknown in branch.unknowns():
+                raise StrictCommitFailed()
 
         if timestamp is None:
             self.timestamp = time.time()

=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2005-10-26 13:57:50 +0000
+++ bzrlib/errors.py	2005-10-27 03:26:19 +0000
@@ -187,6 +187,8 @@
 class PointlessCommit(BzrNewError):
     """No changes to commit"""
 
+class StrictCommitFailed(Exception):
+    """Commit refused because there are unknowns in the tree."""
 
 class NoSuchRevision(BzrError):
     def __init__(self, branch, revision):

=== modified file 'bzrlib/selftest/__init__.py'
--- bzrlib/selftest/__init__.py	2005-10-27 00:53:09 +0000
+++ bzrlib/selftest/__init__.py	2005-10-27 03:26:19 +0000
@@ -306,7 +306,7 @@
         return self.run_bzr_captured(cmd.split())[0]
 
     def run_bzr_captured(self, argv, retcode=0):
-        """Invoke bzr and return (result, stdout, stderr).
+        """Invoke bzr and return (stdout, stderr).
 
         Useful for code that wants to check the contents of the
         output, the way error messages are presented, etc.

=== modified file 'bzrlib/selftest/test_commit.py'
--- bzrlib/selftest/test_commit.py	2005-10-20 04:08:12 +0000
+++ bzrlib/selftest/test_commit.py	2005-10-26 10:03:47 +0000
@@ -276,6 +276,15 @@
         self.assertRaises(StrictCommitFailed, b.commit,
             message='add hello but not goodbye', strict=True)
 
+    def test_strict_commit_without_unknowns(self):
+        """Try and commit with no unknown files and strict = True,
+        should work."""
+        from bzrlib.errors import StrictCommitFailed
+        b = Branch.initialize('.')
+        file('hello', 'w').write('hello world')
+        b.add('hello')
+        b.commit(message='add hello', strict=True)
+
     def test_nonstrict_commit(self):
         """Try and commit with unknown files and strict = False, should work."""
         b = Branch.initialize('.')
@@ -284,6 +293,14 @@
         file('goodbye', 'w').write('goodbye cruel world!')
         b.commit(message='add hello but not goodbye', strict=False)
 
+    def test_nonstrict_commit_without_unknowns(self):
+        """Try and commit with no unknown files and strict = False,
+        should work."""
+        b = Branch.initialize('.')
+        file('hello', 'w').write('hello world')
+        b.add('hello')
+        b.commit(message='add hello', strict=False)
+
     def test_signed_commit(self):
         import bzrlib.gpg
         import bzrlib.commit as commit

